Class: Google::Cloud::Debugger::V2::Debuggee

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/devtools/clouddebugger/v2/data.rb

Overview

Represents the debugged application. The application may include one or more replicated processes executing the same code. Each of these processes is attached with a debugger agent, carrying out the debugging commands. Agents attached to the same debuggee identify themselves as such by using exactly the same Debuggee message value when registering.

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#agent_version::String



470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470

class Debuggee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#description::String



470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470

class Debuggee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#ext_source_contexts::Array<::Google::Devtools::Source::V1::ExtendedSourceContext>



470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470

class Debuggee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#id::String



470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470

class Debuggee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#is_disabled::Boolean



470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470

class Debuggee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#is_inactive::Boolean



470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470

class Debuggee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}



470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470

class Debuggee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#project::String



470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470

class Debuggee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#source_contexts::Array<::Google::Devtools::Source::V1::SourceContext>



470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470

class Debuggee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#status::Google::Cloud::Debugger::V2::StatusMessage



470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470

class Debuggee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#uniquifier::String



470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470

class Debuggee
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end