Class: Google::Cloud::Debugger::V2::Debuggee
- Inherits:
-
Object
- Object
- Google::Cloud::Debugger::V2::Debuggee
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/devtools/clouddebugger/v2/data.rb
Overview
Represents the debugged application. The application may include one or more replicated processes executing the same code. Each of these processes is attached with a debugger agent, carrying out the debugging commands. Agents attached to the same debuggee identify themselves as such by using exactly the same Debuggee message value when registering.
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#agent_version ⇒ ::String
Version ID of the agent.
-
#description ⇒ ::String
Human readable description of the debuggee.
-
#ext_source_contexts ⇒ ::Array<::Google::Devtools::Source::V1::ExtendedSourceContext>
References to the locations and revisions of the source code used in the deployed application.
-
#id ⇒ ::String
Unique identifier for the debuggee generated by the controller service.
-
#is_disabled ⇒ ::Boolean
If set to
true, indicates that the agent should disable itself and detach from the debuggee. -
#is_inactive ⇒ ::Boolean
If set to
true, indicates that Controller service does not detect any activity from the debuggee agents and the application is possibly stopped. -
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
A set of custom debuggee properties, populated by the agent, to be displayed to the user.
-
#project ⇒ ::String
Project the debuggee is associated with.
-
#source_contexts ⇒ ::Array<::Google::Devtools::Source::V1::SourceContext>
References to the locations and revisions of the source code used in the deployed application.
-
#status ⇒ ::Google::Cloud::Debugger::V2::StatusMessage
Human readable message to be displayed to the user about this debuggee.
-
#uniquifier ⇒ ::String
Uniquifier to further distinguish the application.
Instance Attribute Details
#agent_version ⇒ ::String
470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470 class Debuggee include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#description ⇒ ::String
470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470 class Debuggee include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#ext_source_contexts ⇒ ::Array<::Google::Devtools::Source::V1::ExtendedSourceContext>
470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470 class Debuggee include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#id ⇒ ::String
470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470 class Debuggee include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#is_disabled ⇒ ::Boolean
470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470 class Debuggee include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#is_inactive ⇒ ::Boolean
470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470 class Debuggee include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470 class Debuggee include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#project ⇒ ::String
470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470 class Debuggee include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#source_contexts ⇒ ::Array<::Google::Devtools::Source::V1::SourceContext>
470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470 class Debuggee include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#status ⇒ ::Google::Cloud::Debugger::V2::StatusMessage
470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470 class Debuggee include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#uniquifier ⇒ ::String
470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'proto_docs/google/devtools/clouddebugger/v2/data.rb', line 470 class Debuggee include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |